@@ -6,11 +6,4 @@ TAG=$(echo plexus-containers-$2 | sed 's/~\(alpha\|beta\)/-\1-/')
 
 svn export http://svn.codehaus.org/plexus/plexus-containers/tags/$TAG $DIR
 tar -c -z -f $TAR $DIR
-rm -rf $DIR
-
-# move to directory 'tarballs'
-if [ -r .svn/deb-layout ]; then
-  . .svn/deb-layout
-  mv $TAR $origDir
-  echo "moved $TAR to $origDir"
-fi
+rm -rf $DIR
\ No newline at end of file
